naive-bayes-classifier
======================

yet another general purpose naive bayesian classifier. (under heavy development)

## TODO
* inline docs
* unit-tests
* examples


## AUTHORS
* Mustafa Atik @muatik
* Nejdet Yucesoy @nejdetckenobi
